@@ -6,6 +6,10 @@ Notes
 Similar to deriv_data.pro in IDL SPEDAS.
 
 """
+import logging
+
+import numpy as np
+
 import pyspedas
 import pytplot
 
@@ -35,7 +39,7 @@ def deriv_data(names, new_names=None, suffix=None, overwrite=None):
     old_names = pyspedas.tnames(names)
 
     if len(old_names) < 1:
-        print('deriv_data error: No pytplot names were provided.')
+        logging.error('deriv_data error: No pytplot names were provided.')
         return
 
     if suffix is None:
@@ -55,13 +59,6 @@ def deriv_data(names, new_names=None, suffix=None, overwrite=None):
         n_names = [s + suffix for s in old_names]
 
     for i, old in enumerate(old_names):
-        new = n_names[i]
-
-        if new != old:
-            pyspedas.tcopy(old, new)
-
-        data = pytplot.data_quants[new]
-        data_new = data.differentiate('time').copy()
-        pytplot.data_quants[new].values = data_new.values
-
-        print('deriv_data was applied to: ' + new)
+        data = pytplot.get_data(old, dt=True)
+        pytplot.store_data(n_names[i], data={'x': data.times, 'y': np.gradient(data.y)})
+        logging.info('deriv_data was applied to: ' + n_names[i])
