@@ -1,4 +1,3 @@
-
 import os
 import logging
 import numpy as np
@@ -9,9 +8,6 @@ from pyspedas import time_double
 from pyspedas.utilities.download import download
 from pyspedas.mms.mms_config import CONFIG
 
-logging.captureWarnings(True)
-logging.basicConfig(format='%(asctime)s: %(message)s', datefmt='%d-%b-%y %H:%M:%S', level=logging.INFO)
-
 
 def mms_load_brst_segments(trange=None, suffix=''):
     '''
