@@ -18,8 +18,6 @@ from .mms_login_lasp import mms_login_lasp
 from .mms_file_filter import mms_file_filter
 from .mms_load_data_spdf import mms_load_data_spdf
 
-logging.captureWarnings(True)
-logging.basicConfig(format='%(asctime)s: %(message)s', datefmt='%d-%b-%y %H:%M:%S', level=logging.INFO)
 
 def mms_load_data(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate='srvy', level='l2', 
     instrument='fgm', datatype='', varformat=None, prefix='', suffix='', get_support_data=False, time_clip=False, 
